Learn R Programming

bioRad (version 0.12.0)

min_package_version: Identify minimum required package version of dependencies.

Description

Identify the minimum required package version of dependencies listed in Suggests or Imports of the DESCRIPTION file.

Usage

min_package_version(pkg)

Value

A character string with the numeric version. When no version is specified or the package is not listed in Suggests or Depends a value NULL is returned.

Arguments

pkg

A character string with a package name.