- file
A string containing the path to a polar volume file
- param
An atomic vector of character strings, containing the names
of scan parameters to read. To read all scan parameters use 'all'.
- sort
A logical value, when TRUE sort scans ascending
by elevation.
- lat
Latitude in decimal degrees of the radar position. If not
specified, value stored in file is used. If specified, value stored in
file is overwritten.
- lon
Longitude in decimal degrees of the radar position. If not
specified, value stored in file is used. If specified, value stored in
file is overwritten.
- height
Height of the center of the antenna in meters above sea
level. If not specified, value stored in file is used. If specified, value
stored in file is overwritten.
- elev_min
Minimum scan elevation to read in degrees.
- elev_max
Maximum scan elevation to read in degrees.
- verbose
A logical value, whether to print messages (TRUE)
to console.
- mount
(deprecated) A character string with the mount point (a directory path)
for the Docker container.
- local_install
(deprecated) String with path to local vol2bird installation,
to use local installation instead of Docker container